==> kara-uc-1.1.16.tgz: package/src/kara-uc/components/UCInfo/intro/index.js <==
import React from 'react'
import tost from "kara-module-tost";
import css from '../index.scss'

export default class Intro extends React.Component{
  constructor(props)
  {
    super(props)
    this.state = {
      editSign: false,
      changeIntro: '',
    }
    this.inputSign = React.createRef()
  }
  editSignature = () => {
    this.setState({editSign: !this.state.editSign}, ()=>{this.inputSign.current.focus()})
  }

  updateSign = (e) => {
    const value = e.target.value
    const {signature='',httpAgent, updateSign, lang} = this.props
    if(value.trim() !== signature){
      httpAgent.post('/sdm/signature',{
        nickName: value
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') {
            updateSign(value)
            tost({type:'success',msg:lang.updateSuccess,time:4})
          }
          else {
            tost({type:'error',msg:lang.updateError,time:4})
          }
        }
      )
    }
    this.setState({editSign: false})
  }

  onChangeIntro = (e) => {
    const {lang} = this.props
    const value = e.target.value
    if(value.length > 50) {
      tost({type:'warn',msg:lang.noMore50})
    }
    const changeIntro = value.slice(0,50)
    this.setState({changeIntro})
  }

  render() {
    const {changeIntro} = this.state
    const {signature,lang} = this.props
    return(<div className="clearfix">
      <span className='s-hint'>{lang.intro}</span>
      <span className={this.state.editSign ? css.hide : ''}>{signature || lang.noIntro}</span>
      <span className={!this.state.editSign ? css.hide : ''}>
            <textarea
              ref={this.inputSign}
              rows='3'
              className='s-b-primary'
              onBlur={this.updateSign}
              value={changeIntro}
              onChange={this.onChangeIntro}
            />
            </span>
      <span className='s-primary' onClick={this.editSignature}><i className='kuc-iconfont kuc-edit'></i>&nbsp;&nbsp;{lang.edit}</span>
    </div>)
  }
}

==> kara-uc-1.1.29.tgz: package/src/kara-uc/components/UCInfo/intro/index.js <==
import React from 'react'
import tost from "kara-module-tost";
import css from '../index.scss'

export default class Intro extends React.Component{
  constructor(props)
  {
    super(props)
    this.state = {
      editSign: false,
      changeIntro: '',
    }
    this.inputSign = React.createRef()
  }
  editSignature = () => {
    this.setState({editSign: !this.state.editSign}, ()=>{this.inputSign.current.focus()})
  }

  updateSign = (e) => {
    const value = e.target.value
    const {signature='',httpAgent, updateSign, lang} = this.props
    if(value.trim() !== signature){
      httpAgent.post('/sdm/signature',{
        nickName: value
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') {
            updateSign(value)
            tost({type:'success',msg:lang.updateSuccess,time:4})
          }
          else {
            tost({type:'error',msg:lang.updateError,time:4})
          }
        }
      )
    }
    this.setState({editSign: false})
  }

  onChangeIntro = (e) => {
    const {lang} = this.props
    const value = e.target.value
    if(value.length > 50) {
      tost({type:'warn',msg:lang.noMore50})
    } else {
        this.setState({changeIntro: value })
    }
  }

    onKeyDownIntro = (e) => {
      if (e.keyCode === 13) {
          this.updateSign(e)
      }
  }

  render() {
    const {changeIntro} = this.state
    const {signature,lang} = this.props
    return(<div className="clearfix">
      <span className='s-hint'>{lang.intro}</span>
      <span className={this.state.editSign ? css.hide : ''}>{signature || lang.noIntro}</span>
      <span className={!this.state.editSign ? css.hide : ''}>
            <input
              ref={this.inputSign}
              className='s-b-primary'
              type='text'
              value={changeIntro}
              onBlur={this.updateSign}
              onChange={this.onChangeIntro}
              onKeyDown={this.onKeyDownIntro}
            />
            </span>
      <span className='s-primary' onClick={this.editSignature}><i className='kuc-iconfont kuc-edit'></i>&nbsp;&nbsp;{lang.edit}</span>
    </div>)
  }
}
